@@ -1,52 +1,54 @@
-import os
-import numbers
-import json
-import io
 import abc
 import collections
+import io
+import json
+import numbers
+import os
+import subprocess
 from collections import namedtuple
 
 import pandas as pd
-from jinja2 import Environment, select_autoescape, FileSystemLoader
+from jinja2 import Environment, FileSystemLoader, select_autoescape
 
 from celescope.tools.utils import add_log
+from celescope.__init__ import HELP_DICT
+
+
+Metric = namedtuple("Metric", "name value total fraction")
 
 
 def s_common(parser):
     """subparser common arguments
     """
-    parser.add_argument('--outdir', help='output dir', required=True)
-    parser.add_argument('--assay', help='assay', required=True)
-    parser.add_argument('--sample', help='sample name', required=True)
-    parser.add_argument('--thread', help='threads to use', default=4)
-    parser.add_argument('--debug', help='debug', action='store_true')
+    parser.add_argument('--outdir', help='Output diretory.', required=True)
+    parser.add_argument('--assay', help='Assay name.', required=True)
+    parser.add_argument('--sample', help='Sample name.', required=True)
+    parser.add_argument('--thread', help=HELP_DICT['thread'], default=4)
+    parser.add_argument('--debug', help=HELP_DICT['debug'], action='store_true')
     return parser
 
 
 class Step:
-    '''
+    """
     Step class
-    '''
+    """
+
     def __init__(self, args, step_name):
         self.step_name = step_name
         self.args = args
         self.outdir = args.outdir
         self.sample = args.sample
         self.assay = args.assay
-        self.thread = args.thread
+        self.thread = int(args.thread)
         self.debug = args.debug
-        # set 
+        # set
         self.out_prefix = f'{self.outdir}/{self.sample}'
 
-        # out file
-        self.stat_file = f'{self.outdir}/stat.txt'
-
         # important! make outdir before path_dict because path_dict use relative path.
         if not os.path.exists(self.outdir):
             os.system('mkdir -p %s' % self.outdir)
 
         self.metric_list = []
-        self.Metric = namedtuple("Metric", "name value total fraction")
         self.path_dict = {
             "metric": f'{self.outdir}/../.metrics.json',
             "data": f'{self.outdir}/../.data.json'
@@ -59,15 +61,19 @@ class Step:
                 with open(path) as f:
                     self.content_dict[slot] = json.load(f)
 
+        # jinja env
         self.env = Environment(
             loader=FileSystemLoader(os.path.dirname(__file__) + '/../templates/'),
             autoescape=select_autoescape(['html', 'xml'])
         )
 
+        # out file
+        self.stat_file = f'{self.outdir}/stat.txt'
+
     def add_metric(self, name, value=None, total=None, fraction=None):
         '''add metric to metric_list
         '''
-        self.metric_list.append(self.Metric(
+        self.metric_list.append(Metric(
             name=name, value=value, total=total, fraction=fraction
         ))
 
@@ -82,7 +88,7 @@ class Step:
                 fraction = metric.value / metric.total
             if fraction:
                 fraction = round(fraction, 4)
-            metric_list.append(self.Metric(
+            metric_list.append(Metric(
                 name=metric.name,
                 value=metric.value,
                 total=metric.total,
@@ -91,26 +97,25 @@ class Step:
         self.metric_list = metric_list
 
     def metric_list_to_stat(self):
-        f_stat = open(self.stat_file, 'w')
-        for metric in self.metric_list:
-            line = f'{metric.name}: '
-            value = metric.value
-            fraction = metric.fraction
-            value_bool = value == 0 or value
-            fraction_bool = fraction == 0 or fraction
-            if fraction_bool:
-                fraction = round(fraction * 100, 2)
-            if value_bool:
-                if isinstance(value, numbers.Number):
-                    line += format(value, ',')
-                    if fraction_bool:
-                        line += f'({fraction}%)'
-                else:
-                    line += value
-            elif fraction_bool:
-                line += f'{fraction}%'
-            f_stat.write(line + '\n')
-        f_stat.close()
+        with open(self.stat_file, 'w') as stat_handle:
+            for metric in self.metric_list:
+                line = f'{metric.name}: '
+                value = metric.value
+                fraction = metric.fraction
+                value_bool = value == 0 or value
+                fraction_bool = fraction == 0 or fraction
+                if fraction_bool:
+                    fraction = round(fraction * 100, 2)
+                if value_bool:
+                    if isinstance(value, numbers.Number):
+                        line += format(value, ',')
+                        if fraction_bool:
+                            line += f'({fraction}%)'
+                    else:
+                        line += value
+                elif fraction_bool:
+                    line += f'{fraction}%'
+                stat_handle.write(line + '\n')
 
     def dump_content(self, slot):
         '''dump content to json file
@@ -144,7 +149,7 @@ class Step:
         metrics = dict()
         for metric_name, string in dic.items():
             bool_fraction = False
-            bool_value = False 
+            bool_value = False
             if '%' in string:
                 bool_fraction = True
                 if "(" in string:
@@ -152,17 +157,17 @@ class Step:
             chars = [',', '%', ')']
             for character in chars:
                 string = string.replace(character, '')
-            
+
             if bool_fraction:
-                if bool_value: # case 2
+                if bool_value:  # case 2
                     value, fraction = string.split('(')
                     fraction = round(float(fraction) / 100, 4)
                     metrics[metric_name] = int(value)
                     metrics[metric_name + ' Fraction'] = fraction
-                else: # case 3
+                else:  # case 3
                     fraction = round(float(string) / 100, 4)
                     metrics[metric_name] = fraction
-            else: # case 1
+            else:  # case 1
                 value = string
                 if '.' in string:
                     try:
@@ -218,8 +223,14 @@ class Step:
         self.dump_content(slot="metric")
         self.render_html()
 
+    @add_log
+    def debug_subprocess_call(self, cmd):
+        '''
+        debug subprocess call
+        '''
+        self.debug_subprocess_call.logger.debug(f'cmd: {cmd}')
+        subprocess.check_call(cmd, shell=True)
+
     @abc.abstractmethod
     def run(self):
         return
-
-
